import 'package:parodia_admin/core/dto/address.dto.dart';
import 'package:parodia_admin/core/dto/base.dto.dart';
import 'package:parodia_admin/core/dto/campaign.dto.dart';
import 'package:parodia_admin/core/dto/stock.dto.dart';
import 'package:parodia_admin/core/dto/store.dto.dart';
import 'package:parodia_admin/core/dto/tax.dto.dart';

class OrderDTO extends BaseDTO {
  String? status;
  String? type;
  bool? isPaid;
  bool? isTest;
  String? customerNote;
  String? storeNote;
  String? paymentMethod;
  StoreDTO? store;
  List<CampaignDTO>? campaigns;
  Customer? customer;
  AddressDTO? billingAddress;
  AddressDTO? shippingAddress;
  List<Items>? items;
  List<Invoices>? invoices;

  OrderDTO(
      {super.id,
      super.createdAt,
      super.updatedAt,
      super.isActive,
      super.isDeleted,
      this.status,
      this.type,
      this.isPaid,
      this.isTest,
      this.customerNote,
      this.storeNote,
      this.paymentMethod,
      this.store,
      this.campaigns,
      this.customer,
      this.billingAddress,
      this.shippingAddress,
      this.items,
      this.invoices});

  OrderDTO.fromJson(Map<String, dynamic> json) : super.fromJson(json) {
    status = json['status'];
    type = json['type'];
    isPaid = json['isPaid'];
    isTest = json['isTest'];
    customerNote = json['customerNote'];
    storeNote = json['storeNote'];
    paymentMethod = json['paymentMethod'];
    store = json['store'] != null ? StoreDTO.fromJson(json['store']) : null;
    if (json['campaigns'] != null) {
      campaigns = <CampaignDTO>[];
      json['campaigns'].forEach((v) {
        campaigns!.add(CampaignDTO.fromJson(v));
      });
    }
    customer =
        json['customer'] != null ? Customer.fromJson(json['customer']) : null;
    billingAddress = json['billingAddress'] != null
        ? AddressDTO.fromJson(json['billingAddress'])
        : null;
    shippingAddress = json['shippingAddress'] != null
        ? AddressDTO.fromJson(json['shippingAddress'])
        : null;
    if (json['items'] != null) {
      items = <Items>[];
      json['items'].forEach((v) {
        items!.add(Items.fromJson(v));
      });
    }
    if (json['invoices'] != null) {
      invoices = <Invoices>[];
      json['invoices'].forEach((v) {
        invoices!.add(Invoices.fromJson(v));
      });
    }
  }

  @override
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = super.toJson();
    data['status'] = status;
    data['type'] = type;
    data['isPaid'] = isPaid;
    data['isTest'] = isTest;
    data['customerNote'] = customerNote;
    data['storeNote'] = storeNote;
    data['paymentMethod'] = paymentMethod;
    if (store != null) {
      data['store'] = store!.toJson();
    }
    if (campaigns != null) {
      data['campaigns'] = campaigns!.map((v) => v.toJson()).toList();
    }
    if (customer != null) {
      data['customer'] = customer!.toJson();
    }
    if (billingAddress != null) {
      data['billingAddress'] = billingAddress!.toJson();
    }
    if (shippingAddress != null) {
      data['shippingAddress'] = shippingAddress!.toJson();
    }
    if (invoices != null) {
      data['invoices'] = invoices!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Customer {
  String? id;
  String? createdAt;
  String? email;
  String? passwordChangedAt;
  bool? isGuest;
  bool? isTest;
  String? type;
  CustomerDetail? detail;
  StoreDTO? store;

  Customer(
      {this.id,
      this.createdAt,
      this.email,
      this.passwordChangedAt,
      this.isGuest,
      this.isTest,
      this.type,
      this.detail,
      this.store});

  Customer.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    email = json['email'];
    passwordChangedAt = json['passwordChangedAt'];
    isGuest = json['isGuest'];
    isTest = json['isTest'];
    type = json['type'];
    detail =
        json['detail'] != null ? CustomerDetail.fromJson(json['detail']) : null;
    store = json['store'] != null ? StoreDTO.fromJson(json['store']) : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['email'] = email;
    data['passwordChangedAt'] = passwordChangedAt;
    data['isGuest'] = isGuest;
    data['isTest'] = isTest;
    data['type'] = type;
    if (detail != null) {
      data['detail'] = detail!.toJson();
    }
    if (store != null) {
      data['store'] = store!.toJson();
    }
    return data;
  }
}

class CustomerDetail {
  String? id;
  String? createdAt;
  String? name;
  String? surname;
  bool? isVerified;
  String? phoneNumber;
  String? socialSecurityNo;
  String? birthday;
  String? gender;
  String? companyName;
  String? taxOffice;
  String? taxNumber;
  String? fullName;

  CustomerDetail(
      {this.id,
      this.createdAt,
      this.name,
      this.surname,
      this.isVerified,
      this.phoneNumber,
      this.socialSecurityNo,
      this.birthday,
      this.gender,
      this.companyName,
      this.taxOffice,
      this.taxNumber,
      this.fullName});

  CustomerDetail.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    name = json['name'];
    surname = json['surname'];
    isVerified = json['isVerified'];
    phoneNumber = json['phoneNumber'];
    socialSecurityNo = json['socialSecurityNo'];
    birthday = json['birthday'];
    gender = json['gender'];
    companyName = json['companyName'];
    taxOffice = json['taxOffice'];
    taxNumber = json['taxNumber'];
    fullName = json['fullName'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['name'] = name;
    data['surname'] = surname;
    data['isVerified'] = isVerified;
    data['phoneNumber'] = phoneNumber;
    data['socialSecurityNo'] = socialSecurityNo;
    data['birthday'] = birthday;
    data['gender'] = gender;
    data['companyName'] = companyName;
    data['taxOffice'] = taxOffice;
    data['taxNumber'] = taxNumber;
    data['fullName'] = fullName;
    return data;
  }
}

class Items {
  String? id;
  String? createdAt;
  String? status;
  int? quantity;
  String? startDate;
  String? endDate;
  int? basePrice;
  int? discountedPrice;
  double? paidPrice;
  int? taxPercentage;
  double? taxAmount;
  String? currency;
  String? fromCurrency;
  int? currencyRate;
  String? baseCurrency;
  double? baseCurrencyRate;
  String? customerNote;
  String? storeNote;
  StoreDTO? store;
  ProductDetail? productDetail;
  CampaignDTO? campaign;
  List<StockDTO>? stocks;
  List<void>? refunds;
  List<void>? sides;

  Items(
      {this.id,
      this.createdAt,
      this.status,
      this.quantity,
      this.startDate,
      this.endDate,
      this.basePrice,
      this.discountedPrice,
      this.paidPrice,
      this.taxPercentage,
      this.taxAmount,
      this.currency,
      this.fromCurrency,
      this.currencyRate,
      this.baseCurrency,
      this.baseCurrencyRate,
      this.customerNote,
      this.storeNote,
      this.store,
      this.productDetail,
      this.campaign,
      this.stocks,
      this.refunds,
      this.sides});

  Items.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    status = json['status'];
    quantity = json['quantity'];
    startDate = json['startDate'];
    endDate = json['endDate'];
    basePrice = json['basePrice'];
    discountedPrice = json['discountedPrice'];
    paidPrice = json['paidPrice'];
    taxPercentage = json['taxPercentage'];
    taxAmount = json['taxAmount'];
    currency = json['currency'];
    fromCurrency = json['fromCurrency'];
    currencyRate = json['currencyRate'];
    baseCurrency = json['baseCurrency'];
    baseCurrencyRate = json['baseCurrencyRate'];
    customerNote = json['customerNote'];
    storeNote = json['storeNote'];
    store = json['store'] != null ? StoreDTO.fromJson(json['store']) : null;
    productDetail = json['productDetail'] != null
        ? ProductDetail.fromJson(json['productDetail'])
        : null;
    campaign = json['campaign'];
    if (json['stocks'] != null) {
      stocks = <StockDTO>[];
      json['stocks'].forEach((v) {
        stocks!.add(StockDTO.fromJson(v));
      });
    }
    // if (json['refunds'] != null) {
    //   refunds = <Null>[];
    //   json['refunds'].forEach((v) {
    //     refunds!.add(void.fromJson(v));
    //   });
    // }
    // if (json['sides'] != null) {
    //   sides = <Null>[];
    //   json['sides'].forEach((v) {
    //     sides!.add(void.fromJson(v));
    //   });
    // }
  }
}

class ProductDetail {
  String? id;
  String? createdAt;
  String? name;
  String? description;
  String? photoUrl;
  String? type;
  String? variant1Name;
  String? variant2Name;
  String? variant1GroupName;
  String? variant2GroupName;
  List<String>? categories;

  ProductDetail(
      {this.id,
      this.createdAt,
      this.name,
      this.description,
      this.photoUrl,
      this.type,
      this.variant1Name,
      this.variant2Name,
      this.variant1GroupName,
      this.variant2GroupName,
      this.categories});

  ProductDetail.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    name = json['name'];
    description = json['description'];
    photoUrl = json['photoUrl'];
    type = json['type'];
    variant1Name = json['variant1Name'];
    variant2Name = json['variant2Name'];
    variant1GroupName = json['variant1GroupName'];
    variant2GroupName = json['variant2GroupName'];
    categories = json['categories'].cast<String>();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['name'] = name;
    data['description'] = description;
    data['photoUrl'] = photoUrl;
    data['type'] = type;
    data['variant1Name'] = variant1Name;
    data['variant2Name'] = variant2Name;
    data['variant1GroupName'] = variant1GroupName;
    data['variant2GroupName'] = variant2GroupName;
    data['categories'] = categories;
    return data;
  }
}

class Invoices {
  String? id;
  String? createdAt;
  String? no;
  double? price;
  String? currency;
  double? tax;
  double? productDiscount;
  double? cartDiscount;
  double? shippingPrice;
  double? cashOnDeliveryPrice;
  StoreDTO? store;
  List<TaxDTO>? taxDetails;
  void refund;
  String? symbol;

  Invoices(
      {this.id,
      this.createdAt,
      this.no,
      this.price,
      this.currency,
      this.tax,
      this.productDiscount,
      this.cartDiscount,
      this.shippingPrice,
      this.cashOnDeliveryPrice,
      this.store,
      this.taxDetails,
      this.refund,
      this.symbol});

  Invoices.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    createdAt = json['createdAt'];
    no = json['no'];
    price = double.parse(json['price'].toString());
    currency = json['currency'];
    tax = json['tax'];
    productDiscount = double.parse(json['productDiscount'].toString());
    cartDiscount = double.parse(json['cartDiscount'].toString());
    shippingPrice = double.parse(json['shippingPrice'].toString());
    cashOnDeliveryPrice = double.parse(json['cashOnDeliveryPrice'].toString());
    store = json['store'] != null ? StoreDTO.fromJson(json['store']) : null;
    if (json['taxDetails'] != null) {
      taxDetails = <TaxDTO>[];
      json['taxDetails'].forEach((v) {
        taxDetails!.add(TaxDTO.fromJson(v));
      });
    }
    refund = json['refund'];
    symbol = json['symbol'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['createdAt'] = createdAt;
    data['no'] = no;
    data['price'] = price;
    data['currency'] = currency;
    data['tax'] = tax;
    data['productDiscount'] = productDiscount;
    data['cartDiscount'] = cartDiscount;
    data['shippingPrice'] = shippingPrice;
    data['cashOnDeliveryPrice'] = cashOnDeliveryPrice;
    if (store != null) {
      data['store'] = store!.toJson();
    }
    if (taxDetails != null) {
      data['taxDetails'] = taxDetails!.map((v) => v.toJson()).toList();
    }
    //data['refund'] = refund;
    data['symbol'] = symbol;
    return data;
  }
}
