import 'package:parodia_admin/core/dto/base.dto.dart';
import 'package:parodia_admin/core/dto/catalog.dto.dart';
import 'package:parodia_admin/core/dto/feature.dto.dart';
import 'package:parodia_admin/core/dto/photo.dto.dart';
import 'package:parodia_admin/core/dto/product_price.dto.dart';
import 'package:parodia_admin/core/dto/stock.dto.dart';
import 'package:parodia_admin/core/dto/tag.dto.dart';

class ProductDTO extends BaseDTO {
  bool? showInList;
  bool? showInHot;
  bool? showInHome;
  int? sortIndex;
  String? modelCode;
  String? hsCode;
  List<CatalogDTO>? catalogs;
  Detail? detail;
  String? variant1;
  String? variant2;
  List<FeatureDTO>? features;
  List<TagDTO>? tags;
  List<PhotoDTO>? photos;
  List<ProductDTO>? sides;
  List<ProductPriceDTO>? prices;
  List<StockDTO>? stocks;
  List<StockDTO>? inStocks;
  List<StockDTO>? outStocks;

  ProductDTO(
      {super.id,
      super.createdAt,
      super.updatedAt,
      super.isActive,
      super.isDeleted,
      this.showInList,
      this.showInHot,
      this.showInHome,
      this.sortIndex,
      this.modelCode,
      this.hsCode,
      this.detail,
      this.prices,
      this.photos,
      this.sides,
      this.stocks,
      this.inStocks,
      this.outStocks,
      this.catalogs,
      this.variant1,
      this.variant2,
      this.features,
      this.tags});

  ProductDTO.fromJson(Map<String, dynamic> json) : super.fromJson(json) {
    showInList = json['showInList'];
    showInHot = json['showInHot'];
    showInHome = json['showInHome'];
    sortIndex = json['sortIndex'];
    modelCode = json['modelCode'];
    hsCode = json['hsCode'];
    detail = json['detail'] != null ? Detail.fromJson(json['detail']) : null;
    if (json['prices'] != null) {
      prices = <ProductPriceDTO>[];
      json['prices'].forEach((v) {
        prices!.add(ProductPriceDTO.fromJson(v));
      });
    }
    if (json['photos'] != null) {
      photos = <PhotoDTO>[];
      json['photos'].forEach((v) {
        photos!.add(PhotoDTO.fromJson(v));
      });
    }
    if (json['sides'] != null) {
      sides = <ProductDTO>[];
      json['sides'].forEach((v) {
        sides!.add(ProductDTO.fromJson(v));
      });
    }
    if (json['stocks'] != null) {
      stocks = <StockDTO>[];
      json['stocks'].forEach((v) {
        stocks!.add(StockDTO.fromJson(v));
      });
    }
    if (json['inStocks'] != null) {
      inStocks = <StockDTO>[];
      json['inStocks'].forEach((v) {
        inStocks!.add(StockDTO.fromJson(v));
      });
    }
    if (json['outStocks'] != null) {
      outStocks = <StockDTO>[];
      json['outStocks'].forEach((v) {
        outStocks!.add(StockDTO.fromJson(v));
      });
    }
    if (json['catalogs'] != null) {
      catalogs = <CatalogDTO>[];
      json['catalogs'].forEach((v) {
        catalogs!.add(CatalogDTO.fromJson(v));
      });
    }
    variant1 = json['variant1'];
    variant2 = json['variant2'];
    if (json['features'] != null) {
      features = <FeatureDTO>[];
      json['features'].forEach((v) {
        features!.add(FeatureDTO.fromJson(v));
      });
    }
    if (json['tags'] != null) {
      tags = <TagDTO>[];
      json['tags'].forEach((v) {
        tags!.add(TagDTO.fromJson(v));
      });
    }
  }

  @override
  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = super.toJson();
    data['showInList'] = showInList;
    data['showInHot'] = showInHot;
    data['showInHome'] = showInHome;
    data['sortIndex'] = sortIndex;
    data['modelCode'] = modelCode;
    data['hsCode'] = hsCode;
    if (detail != null) {
      data['detail'] = detail!.toJson();
    }
    if (prices != null) {
      data['prices'] = prices!.map((v) => v.toJson()).toList();
    }
    if (photos != null) {
      data['photos'] = photos!.map((v) => v.toJson()).toList();
    }
    if (sides != null) {
      data['sides'] = sides!.map((v) => v.toJson()).toList();
    }
    if (stocks != null) {
      data['stocks'] = stocks!.map((v) => v.toJson()).toList();
    }
    if (inStocks != null) {
      data['inStocks'] = inStocks!.map((v) => v.toJson()).toList();
    }
    if (outStocks != null) {
      data['outStocks'] = outStocks!.map((v) => v.toJson()).toList();
    }
    if (catalogs != null) {
      data['catalogs'] = catalogs!.map((v) => v.toJson()).toList();
    }
    data['variant1'] = variant1;
    data['variant2'] = variant2;
    if (features != null) {
      data['features'] = features!.map((v) => v.toJson()).toList();
    }
    if (tags != null) {
      data['tags'] = tags!.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Detail {
  String? id;
  String? name;
  String? description;
  String? barcode;
  String? slug;

  Detail({this.id, this.name, this.description, this.barcode, this.slug});

  Detail.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    name = json['name'];
    description = json['description'];
    barcode = json['barcode'];
    slug = json['slug'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data['id'] = id;
    data['name'] = name;
    data['description'] = description;
    data['barcode'] = barcode;
    data['slug'] = slug;
    return data;
  }
}
