// POST
// /api/v1/dashboard/categories/slugify

// GET
// /api/v1/dashboard/categories/{id}

// PUT
// /api/v1/dashboard/categories/{id}

// DELETE
// /api/v1/dashboard/categories/{id}

// GET
// /api/v1/dashboard/categories

// POST
// /api/v1/dashboard/categories

// POST
// /api/v1/dashboard/categories/{id}/recover

import 'package:parodia_admin/core/dto/category.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class CategoryRepository {
  ParodiaHTTP? _http;

  CategoryRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<CategoryDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/categories',
      param: id,
    );

    return ResponseItemDTO<CategoryDTO>(
      response: response,
      fromJson: CategoryDTO.fromJson,
    );
  }

  Future<ResponseListDTO<CategoryDTO>> getAll({CategoryQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/categories',
      query: query,
    );

    return ResponseListDTO<CategoryDTO>(
      response: response,
      fromJson: CategoryDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({CategoryBody? category}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/categories',
      data: category,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, CategoryBody? category}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/categories',
      param: id,
      data: category,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/categories',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/categories/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/categories/slugify',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
