// POST
// /api/v1/dashboard/products/slugify

// GET
// /api/v1/dashboard/products/{id}

// PUT
// /api/v1/dashboard/products/{id}

// DELETE
// /api/v1/dashboard/products/{id}

// GET
// /api/v1/dashboard/products

// POST
// /api/v1/dashboard/products

// POST
// /api/v1/dashboard/products/import

// PUT
// /api/v1/dashboard/products/multiple

// DELETE
// /api/v1/dashboard/products/multiple

// POST
// /api/v1/dashboard/products/{id}/recover

import 'package:parodia_admin/core/dto/product.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class ProductRepository {
  ParodiaHTTP? _http;

  ProductRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO> slugify({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/products/slugify',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO<ProductDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/products',
      param: id,
    );

    return ResponseItemDTO<ProductDTO>(
      response: response,
      fromJson: ProductDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ProductDTO>> getAll({ProductQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/products',
      query: query,
    );

    return ResponseListDTO<ProductDTO>(
      response: response,
      fromJson: ProductDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({ProductBody? product}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/products',
      data: product,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, ProductMultiplePutBody? body}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/products/multiple',
      data: body,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> multipleDelete(
      {String? id, ProductMultipleDeleteBody? body}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/products/multiple',
      data: body,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update({String? id, ProductBody? body}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/products',
      param: id,
      data: body,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/products',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/products/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
